==> cms-db_v0.9.tar.gz: admin/locales/it/locale_pages.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['pages'] = array();

$locale['pages']['link_editpage'] = 'Modifica';
$locale['pages']['link_visibility'] = 'Visibilità';
$locale['pages']['link_newpage'] = 'Nuova';
$locale['pages']['link_renamepage'] = 'Cambia nome';
$locale['pages']['link_deletepage'] = 'Cancella';
$locale['pages']['link_sortpages'] = 'Riordina';
$locale['pages']['link_attributes'] = 'Proprietà';
$locale['pages']['desc_saved'] = 'La pagina %s è stata salvata!';
$locale['pages']['link_hide-all'] = 'Nascondi tutte';
$locale['pages']['title_visibility'] = 'Visibilità delle pagine nella navigazione';
$locale['pages']['desc_visibility'] = 'Le pagine nascoste sono segnalate in rosso. La pagina iniziale ("Home") non può essere nascosta. In altre aree di cms -db le pagine nascoste sono indicate dal suffisso DEL. ';
$locale['pages']['title_new'] = 'Nuova pagina';
$locale['pages']['desc_new'] = 'Dove vuoi inserire la nuova pagina?';
$locale['pages']['desc_new-error-name'] = 'Devi inserire un nome per la nuova pagina.';
$locale['pages']['desc_new-error'] = 'Non è possibile creare la nuova pagina.';
$locale['pages']['desc_new-error-count'] = 'Non è possibile creare nuove pagine subordinate a questa pagina.';
$locale['pages']['title_rename'] = 'Cambia nome pagina';
$locale['pages']['button_rename'] = 'Cambia nome';
$locale['pages']['title_delete'] = 'Cancella pagina';
$locale['pages']['title_sort'] = 'Riordina pagine';
$locale['pages']['desc_sort'] = 'Scegli la pagina madre delle pagine secondarie che vuoi riordinare.';
$locale['pages']['desc_sort-manually'] = 'Riordina manualmente';
$locale['pages']['desc_sort-alphabetically'] = 'Metti in ordine alfabetico';
$locale['pages']['desc_sort-no-pages'] = 'Questa pagina non ha pagine secondarie da riordinare.';
$locale['pages']['desc_sort-nojs'] = 'Per poter riordinare le pagine occorre Javascript.';
$locale['pages']['desc_sort-renamed'] = 'Nuovo nome:';
$locale['pages']['desc_sort-urlindex'] = 'Indice URL aggiornato';
$locale['pages']['desc_sort-error'] = 'C\'è stato un errore durante il riordinamento.';
$locale['pages']['title_attributes'] = 'Proprietà delle pagine';
$locale['pages']['link_editattr'] = 'Modifica';
$locale['pages']['link_addattr'] = 'Aggiungi';
$locale['pages']['title_editattr'] = 'Modifica proprietà';
$locale['pages']['desc_delete-attr'] = 'Le proprietà possono essere rimosse cancellando il testo nel campo corrispondente.';
$locale['pages']['label_attr-meta'] = 'Meta tag "%s"';
$locale['pages']['label_attr-custom'] = 'Proprietà personalizzata "%s"';
$locale['pages']['desc_comma-separated'] = '(separate da virgole)';
$locale['pages']['desc_no-attr'] = 'Per questa pagina non sono state definite alcune proprietà.';
$locale['pages']['title_addattr'] = 'Aggiungi proprietà';
$locale['pages']['desc_save-before-adding'] = 'Sei pregato di salvare le modifiche alle proprietà esistenti prima di aggiungerne nuove.';
$locale['pages']['title_attr-meta'] = 'Meta tag';
$locale['pages']['label_attr-meta-type'] = 'Tipo:';
$locale['pages']['title_attr-custom'] = 'Proprietà personalizzata';
$locale['pages']['label_attr-custom-identifier'] = 'Identificativo:';
$locale['pages']['button_add'] = 'Aggiungi';

==> cms-db_v0.9.3.tar.gz: admin/locales/it/locale_pages.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['pages'] = array();

$locale['pages']['desc_recyclebin'] = 'Cliccando su "cancella" la pagina verrà spostata nel cestino.';
$locale['pages']['link_newpage-toplevel'] = 'Crea una pagina madre';
$locale['pages']['link_sortpages-toplevel'] = 'Riordina le pagine madri';
$locale['pages']['desc_hidden'] = 'Nascosto';
$locale['pages']['link_editpage'] = 'Modifica';
$locale['pages']['link_visibility-on'] = 'Mostra nel menu';
$locale['pages']['link_visibility-off'] = 'Nascondi dal menu';
$locale['pages']['link_newpage'] = 'Crea pagina subordinata';
$locale['pages']['link_renamepage'] = 'Cambia nome';
$locale['pages']['link_deletepage'] = 'Cancella';
$locale['pages']['link_sortpages'] = 'Riordina le pagine subordinate';
$locale['pages']['link_attributes'] = 'Cambia le proprietà';
$locale['pages']['desc_saved'] = 'La pagina %s è stata salvata!';
$locale['pages']['title_new'] = 'Nuova pagina';
$locale['pages']['desc_new-subpage'] = 'Quest\'azione crea una nuova pagina subordinata a <i>%s</i>.';
$locale['pages']['desc_new-toplevel'] = 'Quest\'azione crea una nuova pagina madre.';
$locale['pages']['desc_new-error-name'] = 'Devi inserire un nome per la nuova pagina.';
$locale['pages']['desc_new-error'] = 'Non è possibile creare la nuova pagina.';
$locale['pages']['desc_new-error-count'] = 'Non è possibile creare nuove pagine subordinate a questa pagina.';
$locale['pages']['title_rename'] = 'Cambia nome pagina';
$locale['pages']['desc_rename'] = 'Cambia nome della pagina da <i>%s</i> a:';
$locale['pages']['button_rename'] = 'Cambia nome';
$locale['pages']['title_sort'] = 'Riordina pagine';
$locale['pages']['desc_sort'] = 'Scegli la pagina madre delle pagine subordinate che vuoi riordinare.';
$locale['pages']['desc_sort-manually'] = 'Riordina manualmente';
$locale['pages']['desc_sort-alphabetically'] = 'Metti in ordine alfabetico';
$locale['pages']['desc_sort-no-pages'] = 'Questa pagina non ha pagine subordinate da riordinare.';
$locale['pages']['desc_sort-nojs'] = 'Per poter riordinare le pagine occorre Javascript.';
$locale['pages']['desc_sort-renamed'] = 'Nuovo nome:';
$locale['pages']['desc_sort-urlindex'] = 'Indice URL aggiornato';
$locale['pages']['desc_sort-error'] = 'C\'è stato un errore durante il riordinamento.';
$locale['pages']['title_attributes'] = 'Proprietà delle pagine';
$locale['pages']['link_editattr'] = 'Modifica';
$locale['pages']['link_addattr'] = 'Aggiungi';
$locale['pages']['title_editattr'] = 'Modifica proprietà';
$locale['pages']['desc_delete-attr'] = 'Le proprietà possono essere rimosse cancellando il testo nel campo corrispondente.';
$locale['pages']['label_attr-meta'] = 'Meta tag "%s"';
$locale['pages']['label_attr-custom'] = 'Proprietà personalizzata "%s"';
$locale['pages']['desc_comma-separated'] = '(separate da virgole)';
$locale['pages']['desc_no-attr'] = 'Per questa pagina non sono state definite alcune proprietà.';
$locale['pages']['title_addattr'] = 'Aggiungi proprietà';
$locale['pages']['desc_save-before-adding'] = 'Sei pregato di salvare le modifiche alle proprietà esistenti prima di aggiungerne nuove.';
$locale['pages']['title_attr-meta'] = 'Meta tag';
$locale['pages']['label_attr-meta-type'] = 'Tipo:';
$locale['pages']['title_attr-custom'] = 'Proprietà personalizzata';
$locale['pages']['label_attr-custom-identifier'] = 'Identificativo:';
$locale['pages']['button_add'] = 'Aggiungi';
